@@ -17,8 +17,8 @@
  *
  */
 
-#ifndef GDRIVESLAVE_H
-#define GDRIVESLAVE_H
+#ifndef KIO_GDRIVE_H
+#define KIO_GDRIVE_H
 
 #include "pathcache.h"
 
@@ -77,11 +77,24 @@ private:
         PathIsFile = 2
     };
 
+    enum class FetchEntryFlags {
+        None = 0,
+        CurrentDir = 1
+    };
+
+    static KIO::UDSEntry newAccountUDSEntry();
     static KIO::UDSEntry accountToUDSEntry(const QString &accountName);
+    static KIO::UDSEntry sharedDriveToUDSEntry(const KGAPI2::Drive::DrivesPtr &sharedDrive);
 
     void listAccounts();
     void createAccount();
 
+    void listSharedDrivesRoot(const QUrl &url);
+    bool createSharedDrive(const QUrl &url);
+    bool deleteSharedDrive(const QUrl &url);
+    void statSharedDrive(const QUrl &url);
+    KIO::UDSEntry fetchSharedDrivesRootEntry(const QString &accountId, FetchEntryFlags flags = FetchEntryFlags::None);
+
     QString resolveFileIdFromPath(const QString &path, PathFlags flags = None);
 
     Action handleError(const KGAPI2::Job &job, const QUrl &url);
@@ -96,9 +109,12 @@ private:
 
     bool putUpdate(const QUrl &url);
     bool putCreate(const QUrl &url);
-    bool readPutData(QTemporaryFile &tmpFile);
+    bool readPutData(QTemporaryFile &tmpFile, KGAPI2::Drive::FilePtr &file);
 
     /**
+     * Executes a KGAPI2::Job in an event loop, retrying the job until success or failure.
+     * If the Job fails, SlaveBase::error() with an appropriate error message will be called.
+     *
      * @return Whether @p job succeeded.
      */
     bool runJob(KGAPI2::Job &job, const QUrl &url, const QString &accountId);
@@ -110,4 +126,4 @@ private:
 
 };
 
-#endif // GDRIVESLAVE_H
+#endif // KIO_GDRIVE_H
